@@ -1,4 +1,4 @@
-context("\tCompare clusterings")
+context("    Compare clusterings")
 
 # =================================================================================================
 # setup
@@ -15,9 +15,10 @@ with(persistent, {
     test_that("Compare clusterings gives the same results as references.", {
         skip_on_cran()
 
-        expect_equal_to_reference(comp_all, file_name(comp_all))
-        expect_equal_to_reference(comp_gak, file_name(comp_gak))
-        expect_equal_to_reference(comp_dba, file_name(comp_dba))
+        expect_known_value(comp_all, file_name(comp_all))
+        expect_known_value(comp_gak, file_name(comp_gak))
+        expect_known_value(comp_dba, file_name(comp_dba))
+        expect_known_value(comp_sdtwc, file_name(comp_sdtwc))
     })
 })
 
